////////////////////////////////////////////////////////////////////////////////
//
// camera.h
// Declaration de la classe Camera
//
// Editeur de roller coaster
// Projet de realite virtuelle (INF6802)
// Herve Lombaert et Yves Chouinard
// Automne 2005
//
// La classe Camera s'occupe de toutes operations de navigation. Il n'y a
// normalement qu'une seule instance. La methode init() cree un noeud de
// transformation globale destine a etre ajoute au sommet du graphe de scene
// lors de sa creation.
//
// Deux modes de camera : en retrait et premiere personne. Le mode en retrait
// permet de faire l'edition du parcours. Le mode premiere personne permet de
// vivre l'experience totale! La methode toggleMode() permet de passer de
// l'un a l'autre.
//
// En mode premiere personne, on change la position avec la methode
// setFirstPersonPosition(), a laquelle on donne le parcours et la position
// courante sur le parcours. La camera s'occupe du reste.
//
// En mode en retrait, on fait la navigation avec la methode translate() a
// laquelle on donne simplement le deplacement en x et en y (l'axe des z
// represente la verticale).
//
////////////////////////////////////////////////////////////////////////////////


#ifndef CAMERA_H
#define CAMERA_H


#include <OpenSG/OSGTransform.h>
#include "path.h"


#define OFF_CAMERA_MODE			0
#define FIRST_PERSON_CAMERA_MODE	1
#define NB_CAMERA_MODES			2


class Camera
{
private:
	int			mode;
	osg::Matrix		offMatrix;
	Path			path;
	float			walkingDistance;
	osg::TransformPtr	transform;

public:
	osg::NodePtr		init();
	void			setFirstPersonPosition(Path &path, float walkingDistance);
	void			translate(float dx, float dy);
	int			toggleMode() { return mode = (mode + 1) % NB_CAMERA_MODES; calcTransform(); }

private:
	void			calcTransform();
};


#endif
