////////////////////////////////////////////////////////////////////////////////
//
// cursor.h
// Declaration de la classe Cursor
//
// Editeur de roller coaster
// Projet de realite virtuelle (INF6802)
// Herve Lombaert et Yves Chouinard
// Automne 2005
//
// La classe Cursor fournit un curseur (un gros point rouge) qu'on peut
// deplacer avec la wand. Le curseur permet de selectionner un point de
// controle sur le parcours et de le deplacer.
//
// La methode init() cree un noeud OpenSG destine a etre ajoute au graphe de
// scene. Si on est fancy, on peut changer sa couleur avec setColor().
//
// On deplace le curseur en donnant la matrice de la wand a la methode
// setMatrix(). SetMatrix() fait une transformation d'echelle pour que des
// mouvements limites de la wand promenent le curseur sur une distance plus
// grande.
//
// La methode pick() selectionne le point de controle le plus pres de la
// position courante du curseur et donne sa distance via le parametre dist.
// On peut ensuite utiliser la position courante du curseur (donnee par
// getTranslate()) pour modifier la position du point de controle.
//
// Les methodes show(), hide() et toggleVisibility() permettent de montrer le
// curseur en mode d'edition, mais de l'enlever en mode simulation.
//
////////////////////////////////////////////////////////////////////////////////


#ifndef CURSOR_H
#define CURSOR_H


#include <OpenSG/OSGSimpleGeometry.h>
#include <OpenSG/OSGSimpleMaterial.h>
#include "path.h"


class Cursor
{
public:
	osg::NodePtr		init();
	void			setColor(float r, float g, float b, float a);

	void			setMatrix(osg::Matrix mat);
	Path::PointID		pick(Path &path);
	Path::PointID		pick(Path &path, float &dist);
	void			getTranslate(float &x, float &y, float &z);

	void			show();
	void			hide();
	void			toggleVisibility();

private:
	osg::NodePtr		geometry;
	osg::NodePtr		transf;
	osg::SimpleMaterialPtr	material;
};


#endif
