////////////////////////////////////////////////////////////////////////////////
//
// ground.cpp
// Methodes de la classe Ground
//
// Editeur de roller coaster
// Projet de realite virtuelle (INF6802)
// Herve Lombaert et Yves Chouinard
// Automne 2005
//
////////////////////////////////////////////////////////////////////////////////


#include <OpenSG/OSGSceneFileHandler.h>
#include <OpenSG/OSGSimpleMaterial.h>
#include <OpenSG/OSGTransform.h>

#if TEXTURE
#include <OpenSG/OSGImage.h>
#include <OpenSG/OSGSimpleTexturedMaterial.h>
#endif

OSG_USING_NAMESPACE


#include "ground.h"


////////////////////////////////////////////////////////////////////////////////
//
// Ground::init()
//
// Cree le sous-graphe OpenSG contenant le sol et retourne un pointeur au
// noeud de tete pour l'ajouter au graphe de scene. Le sol est compose de
// montagnes prises d'un fichier VRML et d'un lac qui est un plan texture.
//
////////////////////////////////////////////////////////////////////////////////


osg::NodePtr Ground::init()
{
	// Geometry - ground modelled as a flat box
#if 0
	osg::GeometryPtr geo = osg::makeBoxGeo(400.0, 400.0, 1.0, 1, 1, 1);
	osg::beginEditCP(geo);
	  geo->setMaterial(material);
	osg::endEditCP(geo);

	// Geometry node
	geometry = osg::Node::create();
	osg::beginEditCP(geometry);
	  geometry->setCore(geo);
	osg::endEditCP(geometry);
#else
	osg::NodePtr geometry = osg::SceneFileHandler::the().read("wrl/mountain.wrl");
#endif

	// Create transformation
	osg::TransformPtr t = osg::Transform::create();
	osg::NodePtr transf = osg::Node::create();
	osg::Matrix m; m.setScale(3); t->setMatrix(m);
	beginEditCP(transf);
	  transf->setCore(t);
	  transf->addChild(geometry);
	  transf->addChild(initLake());
	endEditCP(transf);

	return transf;
}


////////////////////////////////////////////////////////////////////////////////
//
// Ground::initLake()
//
// Methode privee appelee par init() et qui cree le lac. Le lac est un plan
// texture.
//
////////////////////////////////////////////////////////////////////////////////


osg::NodePtr Ground::initLake()
{
#if TEXTURE
	// Texture
	osg::ImagePtr img = osg::Image::create();
	img->read("images/water.jpg");

	// Green material
	osg::SimpleTexturedMaterialPtr material = osg::SimpleTexturedMaterial::create();
	beginEditCP(material);
	  material->setImage(img);
	endEditCP(material);
#else
        osg::SimpleMaterialPtr material = osg::SimpleMaterial::create();
	osg::beginEditCP(material);
	  material->setAmbient(osg::Color3f(0.1, 0.5, 0.7));
	  material->setDiffuse(osg::Color3f(0.1, 0.5, 0.7));
	osg::endEditCP(material);
#endif

	// Plane
	osg::NodePtr plane = osg::makePlane(100,100,1,1);
	osg::GeometryPtr geo = osg::GeometryPtr::dcast(plane->getCore());
	beginEditCP(geo);
	  geo->setMaterial(material);
	endEditCP(geo);

	// Create transformation
	osg::TransformPtr t = osg::Transform::create();
	osg::Matrix m; m.setTranslate(0,0,-5);
	beginEditCP(t);
	  t->setMatrix(m);
	endEditCP(t);

	// Transformation node
	osg::NodePtr transf = osg::Node::create();
	beginEditCP(transf);
	  transf->setCore(t);
	  transf->addChild(plane);
	endEditCP(transf);

	return transf;
}
