////////////////////////////////////////////////////////////////////////////////
//
// rc.h
// Declaration de la classe RC
//
// Editeur de roller coaster
// Projet de realite virtuelle (INF6802)
// Herve Lombaert et Yves Chouinard
// Automne 2005
//
// La classe RC realise l'application d'Editeur de roller coaster, developpee
// avec VR Juggler et OpenSG. L'application permet d'editer le parcours en
// modifiant ses points de controle, puis de passer en mode simulation pour
// l'experimenter a partir d'une des voitures du train.
//
////////////////////////////////////////////////////////////////////////////////


#ifndef __RC_H
#define __RC_H


#include <gadget/Type/DigitalInterface.h>
#include <gadget/Type/PositionInterface.h>
#include <vpr/Util/Timer.h>
#include <vrj/Draw/OpenSG/OpenSGApp.h>

#include <OpenSG/OSGTransform.h>

#if SOUND
#include <snx/SoundHandle.h>
#endif

#include "camera.h"
#include "speed.h"
#include "structure.h"
#include "train.h"
#include "cursor.h"
#include "ground.h"


#ifdef OPENSG_1_6_0
	#define GET_SCENE_FUNCTION getScene()
#else
	#define GET_SCENE_FUNCTION getSceneRoot()
#endif


class RC : public vrj::OpenSGApp
{
private:
	osg::NodePtr			scene;

	Path				path;
	Speed*				speed;

	Camera				camera;
	Structure			structure;
	Train				train;
	Ground				ground;
	Cursor				cursor;

	bool				paused;
	float				walkingDistance;

	enum Mode {NONE, MOVE_CONTROL_POINT, INSERT_CONTROL_POINT, REMOVE_CONTROL_POINT, MOVE_WORLD};
	Mode				mode;
	Path::PointID			selectedControlPointId;

#if SOUND
	snx::SoundHandle		soundSpeed;
#endif

public:
	RC(vrj::Kernel* kern) : vrj::OpenSGApp(kern) { paused = 0; walkingDistance = 0; }

	virtual void			initScene();
	virtual void			preFrame();
	virtual OSG::NodePtr		GET_SCENE_FUNCTION { return scene; }

	gadget::PositionInterface	mHead;
	gadget::PositionInterface	mWand;
	gadget::DigitalInterface	mButton0;
	gadget::DigitalInterface	mButton1;
	gadget::DigitalInterface	mButton2;
	vpr::Interval			mTimeStamp;
	vpr::Interval			mLastTiming;

private:
	osg::NodePtr			initLight();
	osg::NodePtr			RC::initHouse();
	osg::NodePtr			RC::initSky();
};


#endif
