////////////////////////////////////////////////////////////////////////////////
//
// structure.h
// Declaration de la classe Structure
//
// Editeur de roller coaster
// Projet de realite virtuelle (INF6802)
// Herve Lombaert et Yves Chouinard
// Automne 2005
//
// La classe Structure d'occupe de creer la structure du roller coaster,
// c'est a dire les deux rails et les points de controle, a partir d'un
// parcours donne.
//
// La methode init() retourne un noeud OpenSG destine a etre ajoute au graphe
// de scene. Le parcours suivi par les rails est determine en appelant la
// methode setPath(). Cette methode est appelee aussi souvent que desire a
// mesure que le parcours est modifie.
//
// Les points de controle peuvent etre rendus visibles ou invisibles avec les
// methode showControlPoints() hideControlPoints() selon qu'on est en mode
// d'edition ou de simulation.
//
// Les rails sont composes du multiples petits bouts de cylindres et les
// points de controle sont representes par des cubes vert transparent.
//
////////////////////////////////////////////////////////////////////////////////


#ifndef STRUCTURE_H
#define STRUCTURE_H


#include <OpenSG/OSGSimpleGeometry.h>
#include <OpenSG/OSGSimpleMaterial.h>

#include "path.h"


class Structure
{
private:
	osg::NodePtr		rootNode;
	osg::NodePtr		controlPointRootNode;
	osg::NodePtr		structureRootNode;

	osg::GeometryPtr	controlPointGeometry;
	osg::GeometryPtr	railSectionGeometry;

	osg::SimpleMaterialPtr	invisibleMaterial;
	osg::SimpleMaterialPtr	normalControlPointMaterial;
	osg::SimpleMaterialPtr	selectedControlPointMaterial;
	osg::SimpleMaterialPtr	structureMaterial;

public:
	osg::NodePtr	init();
	void		setPath(Path path);

	void		showControlPoints();
	void		hideControlPoints();

private:
	void	addNode(osg::NodePtr nodeToAttachTo, osg::Matrix transformMatrix, osg::GeometryPtr objectGeometry);
};


#endif
